	.gnu_attribute 4, 1
	.abicalls
	.text
	.align	2
	.globl	_Z3fooi
	.cfi_sections .eh_frame_entry
$LFB0 = .
	.cfi_startproc
	.cfi_personality_id 0x2
	.set	nomips16
	.set	nomicromips
	.ent	_Z3fooi
	.type	_Z3fooi, @function
_Z3fooi:
	nop
	.end	_Z3fooi
	.size	_Z3fooi, .-_Z3fooi
	.cfi_fde_data 0x4,0x40
	.cfi_endproc
