.*Assembler messages:
.*Error: unrecognized opcode `csrr t0,ustatus'
.*Error: unrecognized opcode `csrwi ustatus,0x0'
.*Error: unrecognized opcode `csrsi ustatus,0x0'
.*Error: unrecognized opcode `csrci ustatus,0x0'
.*Error: unrecognized opcode `csrw ustatus,t0'
.*Error: unrecognized opcode `csrw ustatus,0x0'
.*Error: unrecognized opcode `csrs ustatus,t0'
.*Error: unrecognized opcode `csrs ustatus,0x0'
.*Error: unrecognized opcode `csrc ustatus,t0'
.*Error: unrecognized opcode `csrc ustatus,0x0'
.*Error: unrecognized opcode `csrrwi t0,ustatus,0x0'
.*Error: unrecognized opcode `csrrsi t0,ustatus,0x0'
.*Error: unrecognized opcode `csrrci t0,ustatus,0x0'
.*Error: unrecognized opcode `csrrw t0,ustatus,t0'
.*Error: unrecognized opcode `csrrw t0,ustatus,0x0'
.*Error: unrecognized opcode `csrrs t0,ustatus,t0'
.*Error: unrecognized opcode `csrrs t0,ustatus,0x0'
.*Error: unrecognized opcode `csrrc t0,ustatus,t0'
.*Error: unrecognized opcode `csrrc t0,ustatus,0x0'
.*Error: unrecognized opcode `fence.i'
