/* ETMv4 system registers  */

/* Write from read-only system register.  */
msr trcauthstatus, x0
msr trccidr0, x0
msr trccidr1, x0
msr trccidr2, x0
msr trccidr3, x0
msr trcdevaff0, x0
msr trcdevaff1, x0
msr trcdevarch, x0
msr trcdevid, x0
msr trcdevtype, x0
msr trcidr0 , x0
msr trcidr1, x0
msr trcidr2, x0
msr trcidr3, x0
msr trcidr4, x0
msr trcidr5, x0
msr trcidr6, x0
msr trcidr7, x0
msr trcidr8, x0
msr trcidr9, x0
msr trcidr10, x0
msr trcidr11, x0
msr trcidr12, x0
msr trcidr13, x0
msr trclsr, x0
msr trcoslsr, x0
msr trcpdsr, x0
msr trcpidr0, x0
msr trcpidr1, x0
msr trcpidr2, x0
msr trcpidr3, x0
msr trcpidr4, x0
msr trcpidr5, x0
msr trcpidr6, x0
msr trcpidr7, x0
msr trcstatr, x0
