/* Write to read-only BRBE system registers.  */

msr brbidr0_el1, x0
msr brbsrc0_el1, x0
msr brbsrc1_el1, x0
msr brbsrc2_el1, x0
msr brbsrc3_el1, x0
msr brbsrc4_el1, x0
msr brbsrc5_el1, x0
msr brbsrc6_el1, x0
msr brbsrc7_el1, x0
msr brbsrc8_el1, x0
msr brbsrc9_el1, x0
msr brbsrc10_el1, x0
msr brbsrc11_el1, x0
msr brbsrc12_el1, x0
msr brbsrc13_el1, x0
msr brbsrc14_el1, x0
msr brbsrc15_el1, x0
msr brbsrc16_el1, x0
msr brbsrc17_el1, x0
msr brbsrc18_el1, x0
msr brbsrc19_el1, x0
msr brbsrc20_el1, x0
msr brbsrc21_el1, x0
msr brbsrc22_el1, x0
msr brbsrc23_el1, x0
msr brbsrc24_el1, x0
msr brbsrc25_el1, x0
msr brbsrc26_el1, x0
msr brbsrc27_el1, x0
msr brbsrc28_el1, x0
msr brbsrc29_el1, x0
msr brbsrc30_el1, x0
msr brbsrc31_el1, x0
msr brbtgt0_el1, x0
msr brbtgt1_el1, x0
msr brbtgt2_el1, x0
msr brbtgt3_el1, x0
msr brbtgt4_el1, x0
msr brbtgt5_el1, x0
msr brbtgt6_el1, x0
msr brbtgt7_el1, x0
msr brbtgt8_el1, x0
msr brbtgt9_el1, x0
msr brbtgt10_el1, x0
msr brbtgt11_el1, x0
msr brbtgt12_el1, x0
msr brbtgt13_el1, x0
msr brbtgt14_el1, x0
msr brbtgt15_el1, x0
msr brbtgt16_el1, x0
msr brbtgt17_el1, x0
msr brbtgt18_el1, x0
msr brbtgt19_el1, x0
msr brbtgt20_el1, x0
msr brbtgt21_el1, x0
msr brbtgt22_el1, x0
msr brbtgt23_el1, x0
msr brbtgt24_el1, x0
msr brbtgt25_el1, x0
msr brbtgt26_el1, x0
msr brbtgt27_el1, x0
msr brbtgt28_el1, x0
msr brbtgt29_el1, x0
msr brbtgt30_el1, x0
msr brbtgt31_el1, x0
msr brbinf0_el1, x0
msr brbinf1_el1, x0
msr brbinf2_el1, x0
msr brbinf3_el1, x0
msr brbinf4_el1, x0
msr brbinf5_el1, x0
msr brbinf6_el1, x0
msr brbinf7_el1, x0
msr brbinf8_el1, x0
msr brbinf9_el1, x0
msr brbinf10_el1, x0
msr brbinf11_el1, x0
msr brbinf12_el1, x0
msr brbinf13_el1, x0
msr brbinf14_el1, x0
msr brbinf15_el1, x0
msr brbinf16_el1, x0
msr brbinf17_el1, x0
msr brbinf18_el1, x0
msr brbinf19_el1, x0
msr brbinf20_el1, x0
msr brbinf21_el1, x0
msr brbinf22_el1, x0
msr brbinf23_el1, x0
msr brbinf24_el1, x0
msr brbinf25_el1, x0
msr brbinf26_el1, x0
msr brbinf27_el1, x0
msr brbinf28_el1, x0
msr brbinf29_el1, x0
msr brbinf30_el1, x0
msr brbinf31_el1, x0
