	.file	"dw2-decodedline.c"
	.file 1 "dw2-decodedline.c"
	.file 2 "directory/file1.c"
	.text
.globl f1
	.type	f1, %function
f1:
	.loc 2 1 0
	l.nop
	.size	f1, .-f1
.globl main
	.type	main, %function
main:
	.loc 1 2 0
	l.nop
	.size	main, .-main
