.*: Assembler messages:
.*:27: Warning: macro instruction expanded into multiple instructions
.*:28: Warning: macro instruction expanded into multiple instructions
.*:29: Warning: macro instruction expanded into multiple instructions
.*:30: Warning: macro instruction expanded into multiple instructions
