.*:     file format elf64-(little|big)aarch64

Contents of the .eh_frame section:

0+0000 0+0044 0+0000 CIE
  Version:               1
  Augmentation:          "zR"
  Code alignment factor: .
  Data alignment factor: -.
  Return address column: 30
  Augmentation data:     1b

  DW_CFA_def_cfa: r31 \(sp\) ofs 0
  DW_CFA_def_cfa: r0 \(x0\) ofs 0
  DW_CFA_offset_extended_sf: r19 \(x19\) at cfa\+16
  DW_CFA_offset_extended_sf: r20 \(x20\) at cfa\+16
  DW_CFA_offset_extended_sf: r21 \(x21\) at cfa\+16
  DW_CFA_offset_extended_sf: r22 \(x22\) at cfa\+16
  DW_CFA_offset_extended_sf: r23 \(x23\) at cfa\+24
  DW_CFA_offset_extended_sf: r24 \(x24\) at cfa\+24
  DW_CFA_offset_extended_sf: r25 \(x25\) at cfa\+24
  DW_CFA_offset_extended_sf: r26 \(x26\) at cfa\+24
  DW_CFA_offset_extended_sf: r27 \(x27\) at cfa\+24
  DW_CFA_offset_extended_sf: r28 \(x28\) at cfa\+32
  DW_CFA_offset_extended_sf: r29 \(x29\) at cfa\+32
  DW_CFA_offset_extended_sf: r30 \(x30\) at cfa\+40
  DW_CFA_offset_extended_sf: r73 \(v9\) at cfa\+8
  DW_CFA_offset_extended_sf: r75 \(v11\) at cfa\+8
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop

0+0048 0+0014 0+004c FDE cie=0+0000 pc=0+8000..0+8040
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop

0+0060 0+0044 0+0000 CIE
  Version:               1
  Augmentation:          "zR"
  Code alignment factor: .
  Data alignment factor: -.
  Return address column: 30
  Augmentation data:     1b

  DW_CFA_def_cfa: r31 \(sp\) ofs 0
  DW_CFA_def_cfa: r0 \(x0\) ofs 0
  DW_CFA_offset_extended_sf: r19 \(x19\) at cfa\+16
  DW_CFA_offset_extended_sf: r20 \(x20\) at cfa\+16
  DW_CFA_offset_extended_sf: r21 \(x21\) at cfa\+16
  DW_CFA_offset_extended_sf: r22 \(x22\) at cfa\+16
  DW_CFA_offset_extended_sf: r23 \(x23\) at cfa\+24
  DW_CFA_offset_extended_sf: r24 \(x24\) at cfa\+24
  DW_CFA_offset_extended_sf: r25 \(x25\) at cfa\+24
  DW_CFA_offset_extended_sf: r26 \(x26\) at cfa\+24
  DW_CFA_offset_extended_sf: r27 \(x27\) at cfa\+24
  DW_CFA_offset_extended_sf: r28 \(x28\) at cfa\+32
  DW_CFA_offset_extended_sf: r29 \(x29\) at cfa\+32
  DW_CFA_offset_extended_sf: r30 \(x30\) at cfa\+40
  DW_CFA_offset_extended_sf: r73 \(v9\) at cfa\+8
  DW_CFA_offset_extended_sf: r74 \(v10\) at cfa\+8
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop

0+00a8 0+0014 0+004c FDE cie=0+0060 pc=0+8040..0+8080
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop
  DW_CFA_nop

