.*Assembler messages:
#...
.*Warning: Read-only CSR is written `csrw cycle,a1'
.*Warning: Read-only CSR is written `csrw time,a1'
.*Warning: Read-only CSR is written `csrw instret,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter3,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter4,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter5,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter6,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter7,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter8,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter9,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter10,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter11,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter12,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter13,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter14,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter15,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter16,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter17,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter18,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter19,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter20,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter21,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter22,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter23,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter24,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter25,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter26,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter27,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter28,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter29,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter30,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter31,a1'
.*Warning: Read-only CSR is written `csrw cycleh,a1'
.*Warning: Read-only CSR is written `csrw timeh,a1'
.*Warning: Read-only CSR is written `csrw instreth,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter3h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter4h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter5h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter6h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter7h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter8h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter9h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter10h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter11h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter12h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter13h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter14h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter15h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter16h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter17h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter18h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter19h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter20h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter21h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter22h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter23h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter24h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter25h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter26h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter27h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter28h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter29h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter30h,a1'
.*Warning: Read-only CSR is written `csrw hpmcounter31h,a1'
.*Warning: Read-only CSR is written `csrw mvendorid,a1'
.*Warning: Read-only CSR is written `csrw marchid,a1'
.*Warning: Read-only CSR is written `csrw mimpid,a1'
.*Warning: Read-only CSR is written `csrw mhartid,a1'
#...
